==> colorscheme-0.3.1.tar.bz2: colorscheme-0.3.1/src/core/gcs-palette.h <==
/*******************************************************************************
 *  PROJECT: GNOME Colorscheme
 *
 *  AUTHOR: Jonathon Jongsma
 *
 *  Copyright (c) 2005 Jonathon Jongsma
 *
 *  License:
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the 
 *    Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
 *    Boston, MA  02111-1307  USA
 *
 *******************************************************************************/

#ifndef __GCS_PALETTE_H
#define __GCS_PALETTE_H

#include <vector>
#include <istream>

#include <gtkmm/button.h>
#include <gtkmm/table.h>
#include <gtkmm/scrolledwindow.h>
#include <gtkmm/expander.h>
#include <glibmm/ustring.h>
#include <libgnomevfsmm/uri.h>

#include "gcs-color.h"
#include "gcs-types.h"

namespace gcs
{
    class Palette
    {
        public:
            Palette(Glib::RefPtr<Gnome::Vfs::Uri> file);
            //~Palette();

            bool set_from_file(Glib::ustring filename);
            bool set_from_string(Glib::ustring& palette_def);
            Glib::ustring get_name(void) const { return m_name; }
            gint size(void) { return m_colors.size(); }
            Glib::ustring get_name(void) { return m_name; }
            gint get_columns(void) { return m_columns; }
            ColorPtr operator[](gint idx) { return m_colors[idx]; }
            // deletes all the colors and clears m_colors
            void reset(void);

#ifdef UNIT_TEST
            friend class PaletteTests;
#endif

        protected:
            bool parse_palette(std::istream& i);
            // only for parsing lines that actually define a color -- not
            // for header lines like "Name: xxx"
            static ColorPtr parse_line(Glib::ustring palette_line);

            Glib::ustring m_name;
            std::vector<ColorPtr> m_colors;
            gint m_columns;
    };

} // namespace gcs

#endif // __GCS_PALETTE_H

==> colorscheme-0.3.91.tar.bz2: colorscheme-0.3.91/src/core/gcs-palette.h <==
/*******************************************************************************
 *  PROJECT: GNOME Colorscheme
 *
 *  AUTHOR: Jonathon Jongsma
 *
 *  Copyright (c) 2005 Jonathon Jongsma
 *
 *  License:
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the 
 *    Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
 *    Boston, MA  02111-1307  USA
 *
 *******************************************************************************/

#ifndef __GCS_PALETTE_H
#define __GCS_PALETTE_H

#include <istream>

#include <gtkmm/button.h>
#include <gtkmm/table.h>
#include <gtkmm/scrolledwindow.h>
#include <gtkmm/expander.h>
#include <gtkmm/liststore.h>
#include <glibmm/ustring.h>

#include "gcs-color.h"
#include "gcs-types.h"

namespace gcs
{
    class Palette : public Gtk::ListStore
    {
        public:
            bool set_from_file(Glib::ustring filename);
            bool set_from_string(Glib::ustring& palette_def);
            Glib::ustring get_name(void) const { return m_name; }
            gint size(void) { return children().size(); }
            Glib::ustring get_name(void) { return m_name; }
            gint get_columns(void) { return m_paletteColumns; }
            Gtk::TreeModel::Row operator[](gint idx) { return children()[idx]; }
            Gtk::TreeModel::Row add(ColorPtr clr);
            // deletes all the colors
            void reset(void);

            ColorPtr get_color(int row_idx);
            tHexString get_hexstring(int row_idx);

            const Gtk::TreeModelColumn<ColorPtr>& get_color_column(void) { return m_modelColumns.m_colColor; }
            const Gtk::TreeModelColumn<Glib::ustring>& get_text_column(void) { return m_modelColumns.m_colText; }

            static Glib::RefPtr<Palette> create(Glib::ustring fname);

#ifdef UNIT_TEST
            friend class PaletteTests;
#endif

        protected:
            Palette(Glib::ustring file);
            //~Palette();

            Gtk::TreeModel::Row append_color(ColorPtr clr);
            bool parse_palette(std::istream& i);
            // only for parsing lines that actually define a color -- not
            // for header lines like "Name: xxx"
            static ColorPtr parse_line(Glib::ustring palette_line);

            Glib::ustring m_name;
            gint m_paletteColumns;

            // store all of the colors in a ListStore
            class ModelColumns : public Gtk::TreeModel::ColumnRecord
            {
                public:
                    ModelColumns() { add(m_colColor); add(m_colText); }
                    Gtk::TreeModelColumn<ColorPtr> m_colColor;
                    Gtk::TreeModelColumn<tHexString> m_colText;
            };

            ModelColumns m_modelColumns;
    };

} // namespace gcs

#endif // __GCS_PALETTE_H
